@@ -36,6 +36,7 @@
 #include <Lum/View.h>
 
 #include <Lum/Dlg/About.h>
+#include <Lum/Dlg/ActionDialog.h>
 #include <Lum/Dlg/Msg.h>
 
 #include <Lum/Model/Action.h>
@@ -76,7 +77,7 @@ public:
   }
 };
 
-class SelectCollection : public Lum::Dialog
+class SelectCollection : public Lum::Dlg::ActionDialog
 {
 private:
   Lum::Model::ActionRef              okAction;
@@ -101,7 +102,7 @@ public:
     }
   }
 
-  void PreInit()
+  Lum::Object* GetContent()
   {
     Lum::Panel            *panel;
     Lum::Table            *table;
@@ -124,12 +125,12 @@ public:
     table->SetDoubleClickAction(okAction);
     panel->Add(table);
 
-    panel->AddSpace();
-    panel->Add(Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction(),true,false));
+    return panel;
+  }
 
-    SetMain(panel);
-
-    Dialog::PreInit();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+  {
+    CreateActionInfosOkCancel(actions,okAction,GetClosedAction());
   }
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
@@ -159,7 +160,7 @@ public:
   }
 };
 
-class SelectLevel : public Lum::Dialog
+class SelectLevel : public Lum::Dlg::ActionDialog
 {
 private:
   Collection                         *collection;
@@ -188,7 +189,7 @@ public:
     }
   }
 
-  void PreInit()
+  Lum::Object* GetContent()
   {
     Lum::Panel       *panel;
     Lum::Table       *table;
@@ -204,12 +205,12 @@ public:
     table->SetDoubleClickAction(okAction);
     panel->Add(table);
 
-    panel->AddSpace();
-    panel->Add(Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction(),true,false));
+    return panel;
+  }
 
-    SetMain(panel);
-
-    Dialog::PreInit();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+  {
+    CreateActionInfosOkCancel(actions,okAction,GetClosedAction());
   }
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
@@ -264,7 +265,7 @@ public:
   }
 };
 
-class SelectTheme : public Lum::Dialog
+class SelectTheme : public Lum::Dlg::ActionDialog
 {
 private:
   Lum::Model::ActionRef              okAction;
@@ -285,7 +286,7 @@ public:
     Observe(selection);
   }
 
-  void PreInit()
+  Lum::Object* GetContent()
   {
     Lum::Panel            *panel;
     Lum::Table            *table;
@@ -308,12 +309,12 @@ public:
     table->SetDoubleClickAction(okAction);
     panel->Add(table);
 
-    panel->AddSpace();
-    panel->Add(Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction(),true,false));
+    return panel;
+  }
 
-    SetMain(panel);
-
-    Dialog::PreInit();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+  {
+    CreateActionInfosOkCancel(actions,okAction,GetClosedAction());
   }
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
@@ -456,13 +457,16 @@ public:
       ->Group(L"Game")
         ->Action(Lum::Def::Action(Lum::Def::Desc(L"Choose collection")
                                   .SetShortcut(Lum::OS::qualifierControl,L"c"),
-                                  categoryAction))
+                                  categoryAction)
+                 .SetOpensDialog())
         ->Action(Lum::Def::Action(Lum::Def::Desc(L"Choose level")
                                   .SetShortcut(Lum::OS::qualifierControl,L"l"),
-                                  levelAction))
+                                  levelAction)
+                 .SetOpensDialog())
         ->Action(Lum::Def::Action(Lum::Def::Desc(L"Choose theme")
                                   .SetShortcut(Lum::OS::qualifierControl,L"t"),
-                                  themeAction))
+                                  themeAction)
+                 .SetOpensDialog())
         ->Separator()
         ->Action(Lum::Def::Action(Lum::Def::Desc(L"Restart level")
                                   .SetShortcut(Lum::OS::qualifierControl,L"r"),
